@@ -25,7 +25,7 @@ def send_log(alert_id, context, payload=None):
     req_url = '{}/alerting/log/{}'.format(base_url, alert_id)
 
     req_body = {
-        "trackback_log": traceback.format_exc(),
+        "traceback_log": traceback.format_exc(),
         "context": context,
         "payload": __set_payload(payload)}
 
@@ -33,7 +33,7 @@ def send_log(alert_id, context, payload=None):
     print(resp.text)
     try:
         if resp.status_code == 200:
-            return resp.json['log_id']
+            return resp.json()['log_id']
     except Exception as err:
         print(err)
     return 'error'
